@@ -26,7 +26,7 @@ import publication
 import aws_cdk.core
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-athena", "1.33.1", __name__, "aws-athena@1.33.1.jsii.tgz")
+from ._jsii import *
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
@@ -64,7 +64,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -78,7 +78,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -140,7 +140,7 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnNamedQueryProps", jsii_struct_bases=[], name_mapping={'database': 'database', 'query_string': 'queryString', 'description': 'description', 'name': 'name'})
 class CfnNamedQueryProps():
-    def __init__(self, *, database: str, query_string: str, description: typing.Optional[str]=None, name: typing.Optional[str]=None):
+    def __init__(self, *, database: str, query_string: str, description: typing.Optional[str]=None, name: typing.Optional[str]=None) -> None:
         """Properties for defining a ``AWS::Athena::NamedQuery``.
 
         :param database: ``AWS::Athena::NamedQuery.Database``.
@@ -242,7 +242,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -265,7 +265,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -364,7 +364,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.EncryptionConfigurationProperty", jsii_struct_bases=[], name_mapping={'encryption_option': 'encryptionOption', 'kms_key': 'kmsKey'})
     class EncryptionConfigurationProperty():
-        def __init__(self, *, encryption_option: str, kms_key: typing.Optional[str]=None):
+        def __init__(self, *, encryption_option: str, kms_key: typing.Optional[str]=None) -> None:
             """
             :param encryption_option: ``CfnWorkGroup.EncryptionConfigurationProperty.EncryptionOption``.
             :param kms_key: ``CfnWorkGroup.EncryptionConfigurationProperty.KmsKey``.
@@ -407,7 +407,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.ResultConfigurationProperty", jsii_struct_bases=[], name_mapping={'encryption_configuration': 'encryptionConfiguration', 'output_location': 'outputLocation'})
     class ResultConfigurationProperty():
-        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]=None, output_location: typing.Optional[str]=None):
+        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]=None, output_location: typing.Optional[str]=None) -> None:
             """
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
             :param output_location: ``CfnWorkGroup.ResultConfigurationProperty.OutputLocation``.
@@ -450,7 +450,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.ResultConfigurationUpdatesProperty", jsii_struct_bases=[], name_mapping={'encryption_configuration': 'encryptionConfiguration', 'output_location': 'outputLocation', 'remove_encryption_configuration': 'removeEncryptionConfiguration', 'remove_output_location': 'removeOutputLocation'})
     class ResultConfigurationUpdatesProperty():
-        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]=None, output_location: typing.Optional[str]=None, remove_encryption_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, remove_output_location: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None):
+        def __init__(self, *, encryption_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.EncryptionConfigurationProperty"]]]=None, output_location: typing.Optional[str]=None, remove_encryption_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, remove_output_location: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None) -> None:
             """
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
             :param output_location: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.OutputLocation``.
@@ -515,7 +515,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.TagsProperty", jsii_struct_bases=[], name_mapping={'tags': 'tags'})
     class TagsProperty():
-        def __init__(self, *, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None):
+        def __init__(self, *, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None) -> None:
             """
             :param tags: ``CfnWorkGroup.TagsProperty.Tags``.
 
@@ -547,7 +547,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.WorkGroupConfigurationProperty", jsii_struct_bases=[], name_mapping={'bytes_scanned_cutoff_per_query': 'bytesScannedCutoffPerQuery', 'enforce_work_group_configuration': 'enforceWorkGroupConfiguration', 'publish_cloud_watch_metrics_enabled': 'publishCloudWatchMetricsEnabled', 'requester_pays_enabled': 'requesterPaysEnabled', 'result_configuration': 'resultConfiguration'})
     class WorkGroupConfigurationProperty():
-        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, requester_pays_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, result_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationProperty"]]]=None):
+        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, requester_pays_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, result_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationProperty"]]]=None) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
             :param enforce_work_group_configuration: ``CfnWorkGroup.WorkGroupConfigurationProperty.EnforceWorkGroupConfiguration``.
@@ -623,7 +623,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.WorkGroupConfigurationUpdatesProperty", jsii_struct_bases=[], name_mapping={'bytes_scanned_cutoff_per_query': 'bytesScannedCutoffPerQuery', 'enforce_work_group_configuration': 'enforceWorkGroupConfiguration', 'publish_cloud_watch_metrics_enabled': 'publishCloudWatchMetricsEnabled', 'remove_bytes_scanned_cutoff_per_query': 'removeBytesScannedCutoffPerQuery', 'requester_pays_enabled': 'requesterPaysEnabled', 'result_configuration_updates': 'resultConfigurationUpdates'})
     class WorkGroupConfigurationUpdatesProperty():
-        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, requester_pays_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, result_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationUpdatesProperty"]]]=None):
+        def __init__(self, *, bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number]=None, enforce_work_group_configuration: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, requester_pays_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, result_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.ResultConfigurationUpdatesProperty"]]]=None) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
             :param enforce_work_group_configuration: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EnforceWorkGroupConfiguration``.
@@ -711,7 +711,7 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-athena.CfnWorkGroupProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'description': 'description', 'recursive_delete_option': 'recursiveDeleteOption', 'state': 'state', 'tags': 'tags', 'work_group_configuration': 'workGroupConfiguration', 'work_group_configuration_updates': 'workGroupConfigurationUpdates'})
 class CfnWorkGroupProps():
-    def __init__(self, *, name: str, description: typing.Optional[str]=None, recursive_delete_option: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, state: typing.Optional[str]=None, tags: typing.Optional["CfnWorkGroup.TagsProperty"]=None, work_group_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationProperty"]]]=None, work_group_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]]=None):
+    def __init__(self, *, name: str, description: typing.Optional[str]=None, recursive_delete_option: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, state: typing.Optional[str]=None, tags: typing.Optional["CfnWorkGroup.TagsProperty"]=None, work_group_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationProperty"]]]=None, work_group_configuration_updates: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]]=None) -> None:
         """Properties for defining a ``AWS::Athena::WorkGroup``.
 
         :param name: ``AWS::Athena::WorkGroup.Name``.
@@ -809,6 +809,11 @@ class CfnWorkGroupProps():
         return 'CfnWorkGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["CfnNamedQuery", "CfnNamedQueryProps", "CfnWorkGroup", "CfnWorkGroupProps", "__jsii_assembly__"]
+__all__ = [
+    "CfnNamedQuery",
+    "CfnNamedQueryProps",
+    "CfnWorkGroup",
+    "CfnWorkGroupProps",
+]
 
 publication.publish()
